@@ -3,8 +3,8 @@ from os.path import join, expanduser, exists, basename
 from gettext import gettext as _
 
 import gtk
-from deskbar.filewatcher import FileWatcher, DirWatcher
-import deskbar, deskbar.indexer, deskbar.handler
+from deskbar.Watcher import FileWatcher, DirWatcher
+import deskbar, deskbar.Indexer, deskbar.Handler
 
 # Check for presence of set to be compatible with python 2.3
 try:
@@ -12,21 +12,21 @@ try:
 except NameError:
 	from sets import Set as set
 
-from deskbar.handlers_browsers import is_preferred_browser
-from deskbar.handlers_browsers import BrowserSmartMatch, BrowserMatch
+from deskbar.BrowserMatch import is_preferred_browser
+from deskbar.BrowserMatch import BrowserSmartMatch, BrowserMatch
 
 def _on_customize_search_engines():
 	pass
 	
 def _check_requirements():
-	if deskbar.UNINSTALLED_DESKBAR:
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+#	if deskbar.UNINSTALLED_DESKBAR:
+#		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	
 	#We will need to pass some preference here to select one/all engines
 	if is_preferred_browser("firefox") or is_preferred_browser("mozilla"):
-		return (deskbar.handler.HANDLER_IS_HAPPY, None, None)
+		return (deskbar.Handler.HANDLER_IS_HAPPY, None, None)
 	else:
-		return (deskbar.handler.HANDLER_IS_NOT_APPLICABLE, "Mozilla/Firefox is not your preferred browser, not using it.", None)
+		return (deskbar.Handler.HANDLER_IS_NOT_APPLICABLE, "Mozilla/Firefox is not your preferred browser, not using it.", None)
 		
 HANDLERS = {
 	"MozillaBookmarksHandler" : {
@@ -46,9 +46,9 @@ USING_FIREFOX = False
 if is_preferred_browser("firefox"):
 	USING_FIREFOX = True
 			
-class MozillaBookmarksHandler(deskbar.handler.Handler):
+class MozillaBookmarksHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "web-bookmark.png")
+		deskbar.Handler.Handler.__init__(self, "stock_bookmark")
 		self._bookmarks = None
 	
 	def initialize(self):
@@ -68,7 +68,7 @@ class MozillaBookmarksHandler(deskbar.handler.Handler):
 	def stop(self):
 		self.watcher.remove_all()
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		# First, check the smart bookmarks, or "keywords", where
 		# "wp Foo" takes you to the wikipedia entry for Foo.
 		x = self.query_smart_bookmarks(query, max)
@@ -79,7 +79,7 @@ class MozillaBookmarksHandler(deskbar.handler.Handler):
 			# then we'll just look up all bookmarks.
 			return self._bookmarks.look_up(query)[:max]
 	
-	def query_smart_bookmarks(self, query, max=5):
+	def query_smart_bookmarks(self, query, max):
 		# if one of the smart bookmarks' shortcuts matches as a prefix,
 		# then only return that bookmark
 		x = query.find(" ")
@@ -88,16 +88,16 @@ class MozillaBookmarksHandler(deskbar.handler.Handler):
 			try:
 				b = self._shortcuts_to_smart_bookmarks_map[prefix]
 				text = query[x+1:]
-				return [BrowserSmartMatch(b._bookmark, b._name, b._url, prefix)]
+				return [BrowserSmartMatch(b.get_handler(), b.name, b.url, prefix, b, icon=b.icon)]
 			except KeyError:
 				# Probably from the b = ... line.  Getting here
 				# means that there is no such shortcut.
 				pass
 		return None
 
-class MozillaSearchHandler(deskbar.handler.Handler):
+class MozillaSearchHandler(deskbar.Handler.Handler):
 	def __init__(self):
-		deskbar.handler.Handler.__init__(self, "web-bookmark.png")
+		deskbar.Handler.Handler.__init__(self, "stock_bookmark")
 		self._smart_bookmarks = None
 	
 	def initialize(self):
@@ -121,7 +121,7 @@ class MozillaSearchHandler(deskbar.handler.Handler):
 	def stop(self):
 		self.watcher.remove_all()
 		
-	def query(self, query, max=5):
+	def query(self, query, max):
 		return self._smart_bookmarks
 		
 class MozillaBookmarksParser(HTMLParser.HTMLParser):
@@ -136,7 +136,7 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 		self.bookmarks = set()
 		self._shortcuts_to_smart_bookmarks_map = {}
 		
-		self._indexer = deskbar.indexer.Index()
+		self._indexer = deskbar.Indexer.Indexer()
 		
 		if USING_FIREFOX:
 			self.indexed_file = self._index_firefox()
@@ -210,9 +210,9 @@ class MozillaBookmarksParser(HTMLParser.HTMLParser):
 				# Reset icon data for the following icon
 				self.icon_data = None
 				
-			bookmark = BrowserMatch(self.handler, self.chars, self.href, pixbuf)
+			bookmark = BrowserMatch(self.handler, self.chars, self.href, icon=pixbuf)
 			if self.shortcuturl != None:
-				bookmark = BrowserSmartMatch(bookmark, self.chars, self.href, self.shortcuturl)
+				bookmark = BrowserSmartMatch(self.handler, self.chars, self.href, self.shortcuturl, bookmark, icon=pixbuf)
 				self._shortcuts_to_smart_bookmarks_map[self.shortcuturl] = bookmark
 			else:
 				self._indexer.add("%s %s" % (self.chars, self.href), bookmark)
@@ -412,20 +412,19 @@ class MozillaSmartBookmarksDirParser:
 					continue
 				else:
 					foundbookmarks.append(bmname)
-					
-				pixbuf = None
+				
+				img = None
 				try:
 					img = [img for img in glob.glob(join(bookmarks_dir, '%s.*' % f[:-4])) if not img.endswith(".src")][0]
-					pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(img, deskbar.ICON_SIZE, deskbar.ICON_SIZE)
-				except Exception, msg:
-					print 'Error:MozillaSmartBookmarksDirParser:Cannot load image:%s' % msg
+				except:
+					pass
 				
 				parser = MozillaSmartBookmarksParser(f)
 				try:
 					parser.parse()
 					infos = parser.get_infos()
-					bookmark = BrowserMatch(handler, infos["name"], infos["url"], pixbuf)
-					bookmark = BrowserSmartMatch(bookmark, infos["name"], infos["action"])
+					bookmark = BrowserMatch(handler, infos["name"], infos["url"], icon=img)
+					bookmark = BrowserSmartMatch(handler, infos["name"], infos["action"], icon=img, bookmark=bookmark)
 					self._smart_bookmarks.append(bookmark)
 				except Exception, msg:
 					print 'Error:MozillaSmartBookmarksDirParser:cannot parse smrt bookmark:%s:bookmark %s' % (msg, f)
